function layoutplot(cfg, data);

% LAYOUTPLOT makes a figure with the 2-D layout of the channel positions
% for topoplotting and the individual channel axes (i.e. width and height
% of the subfigures) for multiplotting. A correct 2-D layout is a
% prerequisite  for plotting the topographical distribution of the
% potential or field distribution, or for plotting timecourses in a
% topographical arrangement.
%
% This function uses the same configuration options as prepare_layout and
% as the topoplotting and multiplotting functions. The difference is that
% this function only plots the layout without any data, which facilitates 
% the validation of your 2-D layout.
%
% Use as
%   layoutplot(cfg, data)
%
% There are several ways in which a 2-D layout can be made: it can be read
% directly from a *.lay file, it can be created based on 3-D electrode or
% gradiometer positions in the configuration or in the data, or it can be
% created based on the specification of an electrode of gradiometer file.
%
% You can specify either one of the following configuration options
%   cfg.layout
%   cfg.elec
%   cfg.grad
%   cfg.elecfile
%   cfg.gradfile
% Alternatively the layout can be constructed from either
%   data.grad
%   data.elec
%
% See also topoplotER, topoplotTFR, multiplotER, multiplotTFR

% Copyright (C) 2006-2007, Robert Oostenveld
%
% $Log: layoutplot.m,v $
% Revision 1.3  2007/03/14 08:56:00  roboos
% changed some documentation
%
% Revision 1.2  2007/03/14 08:53:29  roboos
% changed from using private/createlayout to prepare_layout, changed the lay structure, added some help to clarify the usefullness of this function
%
% Revision 1.1  2006/06/01 11:51:45  roboos
% new implementation
%

if nargin<2
  data = [];
end

% create the layout
lay    = prepare_layout(cfg, data);

% make a figure out of it
X      = lay.pos(:,1);
Y      = lay.pos(:,2);
Width  = lay.width;
Height = lay.height;
Lbl    = lay.label;
figure
plot(X, Y, '.');
text(X, Y, Lbl);
line([X X+Width X+Width X X]',[Y Y Y+Height Y+Height Y]');
