function [x] = fixprecision(x, precision);

% FIXPRECISION ensures that the data matrix has a numeric precision that is
% supported by the Matlab version
%
% Use as
%   [x] = fixprecision(x)
%   [x] = fixprecision(x, 'single')
%   [x] = fixprecision(x, 'double')
%
% If you do not specify the precision, it will be determined base on the
% Matlab version, for versions 7.0 and higher the precision of the data is
% not changed, for version 6.5 and lower the precision will be 'double'.
%
% See also SINGLE, DOUBLE, CLASS

% Copyright (C) 2006, Robert Oostenveld
%
% $Log: fixprecision.m,v $
% Revision 1.1  2006/05/29 08:16:51  roboos
% new helper function
%

if nargin<2
  if matlabversion<7
    % Matlab versions prior to 7.0 cannot perform computations on single
    % precision numbers
    precision = 'double';
  else
    precision = class(x);
  end
end

if ~strcmp(class(x), precision)
  % conversion is needed
  switch precision
    case 'single'
      x = single(x);
    case 'double'
      x = double(x);
    otherwise
      error('unsupported numeric precision');
  end
end

